@@ -4,7 +4,7 @@ use Exporter 'import';
 use Digest::MD5 qw(md5_hex);
 
 use 5.010;
-our $VERSION = '1.617'; # ==> ALSO update the version in the pod text below!
+our $VERSION = '1.618'; # ==> ALSO update the version in the pod text below!
 
 # loaded modules
 our %TAG_HANDLERS;
@@ -333,7 +333,7 @@ DTL::Fast - Perl implementation of Django templating language.
 
 =head1 VERSION
 
-Version 1.617
+Version 1.618
 
 =head1 SYNOPSIS
 
@@ -355,7 +355,7 @@ And load and render it:
 
 =head1 DESCRIPTION
 
-This module is a Perl and stand-alone templating system, cloned from Django templating sytem, described in L<here|https://docs.djangoproject.com/en/1.7/topics/templates/>.
+This module is a Perl and stand-alone templating system, cloned from Django templating sytem, described in L<here|https://docs.djangoproject.com/en/1.8/topics/templates/>.
 
 =head2 Goals
 
@@ -542,9 +542,28 @@ This function returns internal perl eval counter. This counter being increased o
   
 =head1 TEMPLATING LANGUAGE
 
+=head2 Operators and Expressions
+
+Expressions used in C<if> tag consists of variables, operators and brackets. All operators MUST have at least one space symbol before and after it. This is an after-effect of custom parsing algorythm. 
+
+    {% if var1 == var2 %}   # correct
+    {% if var1==var2 %}     # not correct, no spaces around ==
+    
+Module supports following operators (with precedence):
+
+    pow, **                     # left operand in power of the right one
+    defined                     # check if right operand is defined
+    not                         # negating the right operand
+    in, not in                  # check that left operand exists in a hash or an array (right operand)
+    *, /, %, mod                # multiplying, dividing and modulus
+    +, -                        # plus and minus
+    ==, !=, <>, <, >, <=, >=    # comparision operators
+    and                         # logical and
+    or                          # logical or
+
 =head2 Tags
 
-This module supports almost all built-in tags documented on L<official Django site|https://docs.djangoproject.com/en/1.7/ref/templates/builtins/#built-in-tag-reference>. Don't forget to read L<incompatibilities|/INCOMPATIBILITIES WITH DJANGO TEMPLATES> and L<extensions|/EXTENSIONS OF DJANGO TEMPLATES> sections.
+This module supports almost all built-in tags documented on L<official Django site|https://docs.djangoproject.com/en/1.8/ref/templates/builtins/#built-in-tag-reference>. Don't forget to read L<incompatibilities|/INCOMPATIBILITIES WITH DJANGO TEMPLATES> and L<extensions|/EXTENSIONS OF DJANGO TEMPLATES> sections.
 
 =head3 block_super
 
@@ -585,7 +604,7 @@ Works exactly as the C<dump> tag, warns output, instead of putting it into the r
 
 =head2 Filters
 
-This module supports all built-in filters documented on L<official Django site|https://docs.djangoproject.com/en/1.7/ref/templates/builtins/#built-in-filter-reference>. Don't forget to read L<incompatibilities|/INCOMPATIBILITIES WITH DJANGO TEMPLATES> and L<extensions|/EXTENSIONS OF DJANGO TEMPLATES> sections.
+This module supports all built-in filters documented on L<official Django site|https://docs.djangoproject.com/en/1.8/ref/templates/builtins/#built-in-filter-reference>. Don't forget to read L<incompatibilities|/INCOMPATIBILITIES WITH DJANGO TEMPLATES> and L<extensions|/EXTENSIONS OF DJANGO TEMPLATES> sections.
 
 =head3 numberformat
 
@@ -1005,7 +1024,7 @@ Tests shows, that C<DTL::Fast> works 27% faster, than L<C<Dotiac::DTL>> in CGI e
 
 =item * CPAN Ratings: L<http://cpanratings.perl.org/d/DTL-Fast>
 
-=item * Original Django templating documentation: L<https://docs.djangoproject.com/en/1.7/topics/templates/>
+=item * Original Django templating documentation: L<https://docs.djangoproject.com/en/1.8/topics/templates/>
 
 =item * Other implementaion: L<http://search.cpan.org/~maluku/Dotiac-0.8/lib/Dotiac/DTL.pm>
 
