@@ -2,7 +2,7 @@ package DTL::Fast::Expression::Operator::Binary::In;
 use strict; use utf8; use warnings FATAL => 'all';
 use parent 'DTL::Fast::Expression::Operator::Binary';
 
-$DTL::Fast::Expression::Operator::KNOWN{'in'} = __PACKAGE__;
+$DTL::Fast::OPS_HANDLERS{'in'} = __PACKAGE__;
 
 use DTL::Fast::Expression::Operator::Binary::Eq;
 
@@ -95,10 +95,10 @@ sub dispatch
     if( not defined $result )
     {
         die sprintf("Don't know how to check that %s (%s) is in %s (%s)"
-            , $arg1
-            , $arg1_type
-            , $arg2
-            , $arg2_type
+            , $arg1 // 'undef'
+            , $arg1_type // 'undef'
+            , $arg2 // 'undef'
+            , $arg2_type // 'undef'
         );
     }
 
