@@ -30,7 +30,7 @@ sub new
 sub parse_parameters
 {
     my $self = shift;
-    $self->{'template'} = DTL::Fast::Expression->new($self->{'parameter'}, '_template' => $self->{'_template'});
+    $self->{'template'} = DTL::Fast::Expression->new($self->{'parameter'});
     return $self;
 }
 
@@ -49,7 +49,7 @@ sub render
   
     die sprintf(
         "Couldn't find included template %s in directories %s"
-        , $template_name
+        , $template_name // 'undef'
         , join(', ', @{$self->{'dirs'}})
     ) if not defined $result;
   
